@@ -35,4 +35,7 @@
 ;; font and its encoder setup.
 (require 'x0213-font)
 
+;; supplemental configurations.
+(require 'x0213-sup)
+
 (provide 'jisx0213)
