@@ -40,7 +40,7 @@
 ;; 1.80->IMADEGAWA
 ;; 1.90->DAIRI
 ;; 2.00->Kyoto Univ.
-(defconst mucs-version "0.72 (RYOANJI:$BN50B;{(B)")
+(defconst mucs-version "0.73 (ROKUONJI:$B</1q;{(B)")
 
 ;; For error handling.
 
@@ -49,14 +49,11 @@
 ;; Type manager.
 (require 'mucs-type)
 
-;;; fundamental data.
+;;
+;; package require.
+;;
 
-(defvar emacs-value-bits 28)
-(defvar mucs-code-range-bits 27)
-(defvar mucs-code-range-specials 100)
 (defvar mucs-data-path "reldata/")
-(defvar mucs-invalid-code -1
-  "invalid code.  If this value is set, skip operation.")
 
 (defun mucs-require-data (package)
   (or (featurep package)
@@ -83,18 +80,25 @@
 			     package))))))
 	(require package))))
 
+;;; fundamental data.
+
+(defvar emacs-value-bits 28)
+(defvar mucs-code-range-bits 27)
+(defvar mucs-code-range-specials 100)
+(defvar mucs-invalid-code -1
+  "invalid code.  If this value is set, skip operation.")
+
 (defun mucs-max-code ()
-  (- (lsh 1 (- mucs-code-range-bits 2))
-     mucs-code-range-specials 1))
+  (1- (lsh 1 (1- mucs-code-range-bits))))
 
 (defun mucs-special-code (code)
   (if (or (< code 0)
 	  (>= code mucs-code-range-specials))
       (error "Invalid code:%d" code))
-  (+ (mucs-max-code) code 1))
+  (- (lsh 1 mucs-code-range-bits) 1 code))
 
-(defun mucs-code-range-mask ()
-  (- (lsh 1 (1- mucs-code-range-bits)) 1))
+(defun mucs-arithmetic-adjust ()
+  (* 3 (lsh 1 (- mucs-code-range-bits 2))))
 
 (defun mucs-number-mask ()
   (lognot 0))
