@@ -32,6 +32,10 @@
 ;;;   This module provide such facilities, that is APIs for
 ;;;   other applications to use Unicode, UTF, and so on.
 
+;;; private charset definition.
+
+(require 'mule-uni)
+
 ;;; Autoload section
 (autoload 'ucs-to-char "unicode")
 (autoload 'char-to-ucs "unicode")
@@ -42,44 +46,64 @@
 
 ;;; Required for compile, and also persistent section.
 (eval-and-compile
+
 ;
 ; unicode basic translation charset list.
 ;
-
-(defvar unicode-basic-translation-charset-order-list
-  '(ascii
-    latin-iso8859-1
-    latin-iso8859-2
-    latin-iso8859-3
-    latin-iso8859-4
-    cyrillic-iso8859-5
+  (defvar unicode-basic-translation-charset-order-list
+    '(ascii
+      latin-iso8859-1
+      latin-iso8859-2
+      latin-iso8859-3
+      latin-iso8859-4
+      cyrillic-iso8859-5
 					;      arabic-iso8859-6
-    greek-iso8859-7
-    hebrew-iso8859-8
-    latin-iso8859-9
-    ipa
-    japanese-jisx0208
-    japanese-jisx0212
-    chinese-gb2312
-    chinese-cns11643-1 
-    chinese-cns11643-2
-    chinese-cns11643-3
-    chinese-cns11643-4
-    chinese-cns11643-5
-    chinese-cns11643-6
-    chinese-cns11643-7
-    korean-ksc5601
-    latin-jisx0201
-    katakana-jisx0201)
-  "*Charset order used by unicode-basic-translation")
+      greek-iso8859-7
+      hebrew-iso8859-8
+      latin-iso8859-9
+      ipa
+      mule-unicode-0100-24ff
+      japanese-jisx0208
+      japanese-jisx0212
+      chinese-gb2312
+      chinese-cns11643-1 
+      chinese-cns11643-2
+      chinese-cns11643-3
+      chinese-cns11643-4
+      chinese-cns11643-5
+      chinese-cns11643-6
+      chinese-cns11643-7
+      chinese-big5-1
+      chinese-big5-2
+      korean-ksc5601
+      latin-jisx0201
+      katakana-jisx0201
+      thai-tis620) ;;; I'll give high priority in the future. This is a test.
+    "*Charset order used by unicode-basic-translation")
 
 ;
 ; Default translation rule symbol per charset.
 ;
-(defun unicode-get-translation-rule-from-charset (charset)
-  (intern (format "unicode-%s-translation-rule"
-		  (symbol-name charset))))
+  (defun unicode-get-translation-rule-from-charset (charset)
+    (intern (format "unicode-%s-translation-rule"
+		    (symbol-name charset))))
 
+;
+; font encoder charset spec alist
+;
+
+  (defvar unicode-font-encoder-charset-spec-alist
+    (mapcar
+     (lambda (cs)
+       (cons cs
+	     `(list
+	       (mucs-ccl-convert-font-encoding
+		,(charset-dimension cs))
+	       (tae-compile 
+		(quote
+		 ,(unicode-get-translation-rule-from-charset cs)))
+	       (mucs-ccl-flat-code-to-font-encoding 2))))
+     unicode-basic-translation-charset-order-list))
 ;;
 ;; Configuration functions for convenience.
 ;;
@@ -94,7 +118,7 @@
   (defun un-define-encode-template (tr read write)
     (require 'unicode)
     (mucs-ccl-stream-form
-     (mucs-ccl-read 'char-packed-1 read)
+     (mucs-ccl-read 'char-1 read)
      (tae-compile tr nil)
      (mucs-ccl-write write)))
 
@@ -407,7 +431,7 @@
 
  (mucs-define-conversion
   emacs-char-to-ucs-codepoint-conversion
-  (char-packed-1 . ucs-generic)
+  (char-1 . ucs-generic)
   (0 ((tae-compile 'unicode-basic-non-stream-translation-rule nil))))
 
  (mucs-define-conversion
@@ -421,17 +445,7 @@
   unicode-font-encoder
   (font-codepoint . font-codepoint)
   (0 ((mucs-ccl-font-encoder
-       (mapcar
-	(lambda (cs)
-	  (cons cs
-		`(list
-		  (mucs-ccl-convert-font-encoding
-		   ,(charset-dimension cs))
-		  (tae-compile 
-		   (quote
-		    ,(unicode-get-translation-rule-from-charset cs)))
-		  (mucs-ccl-flat-code-to-font-encoding 2))))
-	unicode-basic-translation-charset-order-list)))))
+       unicode-font-encoder-charset-spec-alist))))
 
 ;;
 ;; coding-system-definition.
@@ -633,8 +647,12 @@
 				category-list)))
 ;; setup detect coding priority.
   (if category-list
-      (set-coding-priority
-       category-list)))
+      (progn
+	(set-coding-priority
+	 category-list)
+	(add-hook 'set-language-environment-hook
+		  `(lambda ()
+		     (set-coding-priority (quote ,category-list)))))))
 
 ;
 ; Charset order dynamic modification. (Very simple version!)
