@@ -34,20 +34,37 @@
 			       "./lisp/mucs-ccl.el"
 			       "./lisp/mccl-font.el"
 			       "./lisp/tbl-mg.el"
-			       "./lisp/trans-util.el"
-			       "./lisp/txt-tbl.el"
-			       "./lisp/tae.el"
-			       "./lisp/unicode.el"
-			       "./lisp/utf.el"
-			       "./lisp/un-data.el"
-			       "./lisp/un-tools.el"))
-      (compile-file-list-2nd (if command-line-args-left
-				 (prog1
-				     command-line-args-left
-				   (setq command-line-args-left nil))
-			       '(
-				 "./lisp/un-define.el"
-				 ))))
+				"./lisp/trans-util.el"
+				"./lisp/txt-tbl.el"
+				"./lisp/tae.el"
+				"./lisp/unicode.el"
+				"./lisp/utf.el"
+				"./lisp/un-data.el"
+				"./lisp/un-tools.el"))
+       (compile-file-list-2nd (if command-line-args-left
+				  (prog1
+				      command-line-args-left
+				    (setq command-line-args-left nil))
+				'(
+				  "./lisp/un-define.el"
+				  )))
+       file)
+
+  (message "Remove old byte-compiled files-----")
+  (mapcar 
+   (lambda (x)
+     (setq file (concat
+		 (file-name-sans-extension x)
+		 ".elc"))
+     (if (file-exists-p file)
+	 (progn
+	   (message "Remove %s" file)
+	   (delete-file file)))
+     nil)
+   (append
+    compile-file-list-1st
+    compile-file-list-2nd))
+
   (message "Compiling 1st stage-----")
   (mapcar
    (lambda (file)
